import React from "react";
import { AutoCompleteBaseProps } from "./types";
interface SelectionItem {
    name: string;
}
type MultiAutoCompletePropsValue = SelectionItem[] | string[];
export interface MultiAutoCompleteProps extends Omit<AutoCompleteBaseProps, "value"> {
    /**
     * Prevents adding the same item to the list twice.
     */
    unique: boolean;
    /**
     * Set if custom values (not from list of suggestions) are allowed.
     */
    allowFreeInput?: boolean;
    /**
     *  If true, will show a loading spinner on the right side of the input.
     */
    loading?: boolean;
    /**
     * Use custom renderer for selected items.
     */
    renderMultipleSelection?: ((items: any) => React.ReactNode | null) | null;
    /**
     * Use data list instead of default Chips component. Useful when expecting a lot of data.
     */
    useMultipleSelectionList?: boolean;
    /**
     * Render list item when `useMultipleSelectionList` is used.
     */
    renderListItemLabel?: (item: any) => React.ReactNode;
    /**
     * Render in meta wrapper
     */
    renderListItemOptions?: (item: any) => React.ReactNode | null;
    noResultFound?: React.ReactNode;
    /**
     * Value is an array of strings. But can be undefined.
     */
    value?: MultiAutoCompletePropsValue;
}
interface MultiAutoCompleteState {
    inputValue: string;
    multipleSelectionPage: number;
    multipleSelectionSearch: string;
    reorderFormVisible: string;
    reorderFormValue: string;
}
export declare class MultiAutoComplete extends React.Component<MultiAutoCompleteProps, MultiAutoCompleteState> {
    static defaultProps: Partial<MultiAutoCompleteProps>;
    state: MultiAutoCompleteState;
    /**
     * Helps us trigger some of the downshift's methods (eg. clearSelection) and helps us to avoid adding state.
     */
    private downshift;
    private assignedValueAfterClearing;
    setMultipleSelectionPage: (multipleSelectionPage: number) => void;
    setMultipleSelectionSearch: (multipleSelectionSearch: string) => void;
    getOptions(): any[];
    /**
     * Renders options - based on user's input. It will try to match input text with available options.
     */
    private renderOptions;
    paginateMultipleSelection(): {
        data: {
            option: string | SelectionItem;
            index: number;
        }[];
        meta: {
            hasData: boolean;
            totalCount: number;
            from: number;
            to: number;
            page: number;
            lastPage: number;
            limit: number;
            hasPrevious: boolean;
            hasNext: boolean;
        };
    };
    /**
     * Once added, items can also be removed by clicking on the ✕ icon. This is the method that is responsible for
     * rendering selected items (we are using already existing "Chips" component).
     */
    renderMultipleSelection(): string | number | boolean | Iterable<React.ReactNode> | React.JSX.Element | null | undefined;
    render(): React.JSX.Element;
}
export {};
