import React from "react";
import { FabProps } from "@rmwc/fab";
import { IconProps } from "../Icon/Icon";
import { SyntheticEvent } from "react";
export interface ButtonProps {
    /**
     * Make button flat (only applicable to Primary button).
     */
    flat?: boolean;
    /**
     * Make button smaller.
     */
    small?: boolean;
    /**
     * Returning `any` allows us to pass callbacks to the button without worrying about their
     * specific return types. Buttons don't use return values from callbacks, so we don't have to worry
     * about their return types at all.
     */
    onClick?: (event: React.MouseEvent<any, MouseEvent>) => any;
    /**
     * Label and optionally an icon (using Button.Icon component).
     */
    children?: React.ReactNode;
    /**
     * Show ripple effect on button click.
     */
    ripple?: boolean;
    /**
     * Additional button class name.
     */
    className?: string;
    /**
     * Is button disabled?
     */
    disabled?: boolean;
    /**
     * Additional inline styles.
     */
    style?: {
        [key: string]: any;
    };
    /**
     * ID of the element for testing purposes.
     */
    "data-testid"?: string;
}
/**
 * Shows a default button, used typically when action is not of high priority.
 */
export declare const ButtonDefault: (props: ButtonProps) => React.JSX.Element;
/**
 * Shows primary button, eg. for submitting forms.
 */
export declare const ButtonPrimary: (props: ButtonProps) => React.JSX.Element;
/**
 * Shows a secondary button - eg. for doing a reset on a form.
 */
export declare const ButtonSecondary: (props: ButtonProps) => React.JSX.Element;
export type ButtonFloatingProps = ButtonProps & Omit<FabProps, "icon"> & {
    label?: string | JSX.Element;
    icon?: JSX.Element;
    onMouseDown?: (e: SyntheticEvent) => void;
    onMouseUp?: (e: SyntheticEvent) => void;
};
/**
 * A floating button, shown on the side of the screen, typically used for creating new content or accessing settings.
 */
export declare const ButtonFloating: (props: ButtonFloatingProps) => React.JSX.Element;
/**
 * Shows an icon, suitable to be shown inside of a button.
 */
export declare const ButtonIcon: (props: IconProps) => React.JSX.Element;
