"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ButtonSecondary = exports.ButtonPrimary = exports.ButtonIcon = exports.ButtonFloating = exports.ButtonDefault = void 0;
var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutProperties"));
var _react = _interopRequireDefault(require("react"));
var RmwcButton = _interopRequireWildcard(require("@rmwc/button"));
var _fab = require("@rmwc/fab");
var _Icon = require("../Icon/Icon");
var _classnames = _interopRequireDefault(require("classnames"));
var _Button = require("./Button.styles");
var _excluded = ["disabled", "label", "icon", "onClick", "small", "ripple", "className"];
/**
 * Shows a default button, used typically when action is not of high priority.
 */
var ButtonDefault = exports.ButtonDefault = function ButtonDefault(props) {
  var disabled = props.disabled,
    onClick = props.onClick,
    children = props.children,
    small = props.small,
    ripple = props.ripple,
    _props$className = props.className,
    className = _props$className === void 0 ? "" : _props$className,
    style = props.style;
  return /*#__PURE__*/_react.default.createElement(RmwcButton.Button, {
    style: style,
    disabled: disabled,
    dense: small,
    onClick: onClick,
    ripple: ripple,
    className: (0, _classnames.default)("webiny-ui-button", className),
    "data-testid": props["data-testid"]
  }, children);
};

/**
 * Shows primary button, eg. for submitting forms.
 */
var ButtonPrimary = exports.ButtonPrimary = function ButtonPrimary(props) {
  var disabled = props.disabled,
    onClick = props.onClick,
    children = props.children,
    _props$small = props.small,
    small = _props$small === void 0 ? false : _props$small,
    _props$flat = props.flat,
    flat = _props$flat === void 0 ? false : _props$flat,
    ripple = props.ripple,
    _props$style = props.style,
    style = _props$style === void 0 ? {} : _props$style,
    _props$className2 = props.className,
    className = _props$className2 === void 0 ? null : _props$className2;
  return /*#__PURE__*/_react.default.createElement(RmwcButton.Button, {
    raised: !flat,
    dense: small,
    disabled: disabled,
    unelevated: flat,
    ripple: ripple,
    onClick: onClick,
    style: style,
    className: (0, _classnames.default)("webiny-ui-button webiny-ui-button--primary", className),
    "data-testid": props["data-testid"]
  }, children);
};

/**
 * Shows a secondary button - eg. for doing a reset on a form.
 */
var ButtonSecondary = exports.ButtonSecondary = function ButtonSecondary(props) {
  var disabled = props.disabled,
    onClick = props.onClick,
    children = props.children,
    _props$small2 = props.small,
    small = _props$small2 === void 0 ? false : _props$small2,
    ripple = props.ripple,
    _props$className3 = props.className,
    className = _props$className3 === void 0 ? null : _props$className3,
    _props$style2 = props.style,
    style = _props$style2 === void 0 ? {} : _props$style2;
  return /*#__PURE__*/_react.default.createElement(RmwcButton.Button, {
    disabled: disabled,
    outlined: true,
    dense: small,
    ripple: ripple,
    onClick: onClick,
    style: style,
    className: (0, _classnames.default)("webiny-ui-button webiny-ui-button--secondary", _Button.webinyButtonStyles, className),
    "data-testid": props["data-testid"]
  }, children);
};
/**
 * A floating button, shown on the side of the screen, typically used for creating new content or accessing settings.
 */
var ButtonFloating = exports.ButtonFloating = function ButtonFloating(props) {
  var disabled = props.disabled,
    label = props.label,
    icon = props.icon,
    onClick = props.onClick,
    _props$small3 = props.small,
    small = _props$small3 === void 0 ? false : _props$small3,
    ripple = props.ripple,
    _props$className4 = props.className,
    className = _props$className4 === void 0 ? null : _props$className4,
    rest = (0, _objectWithoutProperties2.default)(props, _excluded);
  return /*#__PURE__*/_react.default.createElement(_fab.Fab, Object.assign({
    "data-testid": props["data-testid"],
    disabled: disabled,
    mini: small,
    onClick: onClick,
    label: label,
    ripple: ripple,
    icon: icon,
    className: (0, _classnames.default)("webiny-ui-button--floating", className)
  }, rest));
};

/**
 * Shows an icon, suitable to be shown inside of a button.
 */
var ButtonIcon = exports.ButtonIcon = function ButtonIcon(props) {
  return /*#__PURE__*/_react.default.createElement(_Icon.Icon, props);
};

//# sourceMappingURL=Button.js.map