"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ColumnsVisibility = void 0;
var _react = _interopRequireWildcard(require("react"));
var _settings = require("@material-design-icons/svg/outlined/settings.svg");
var _Button = require("../Button");
var _Checkbox = require("../Checkbox");
var _Menu = require("../Menu");
var _styled = require("./styled");
var ColumnsVisibility = exports.ColumnsVisibility = function ColumnsVisibility(props) {
  /**
   * `@tanstack/react-table` does not have a simple method to return the header component.
   * The only possible way is to use `flexRenderer`, but this is not working with the current implementation
   * since we don't have access to the header context.
   */
  var getHeaderName = (0, _react.useCallback)(function (column) {
    var header = column.columnDef.header;
    if (typeof header === "string") {
      return header;
    }
    if (typeof header === "function") {
      // @ts-expect-error
      return header();
    }
    return column.id;
  }, []);
  var options = (0, _react.useMemo)(function () {
    return props.columns.filter(function (column) {
      return column.getCanHide();
    }).map(function (column) {
      return {
        id: column.id,
        header: getHeaderName(column),
        onChange: column.toggleVisibility,
        getValue: column.getIsVisible
      };
    });
  }, [props.columns]);
  if (options.length === 0) {
    return null;
  }
  return /*#__PURE__*/_react.default.createElement(_Menu.Menu, {
    handle: /*#__PURE__*/_react.default.createElement(_Button.IconButton, {
      icon: /*#__PURE__*/_react.default.createElement(_settings.ReactComponent, null)
    })
  }, /*#__PURE__*/_react.default.createElement(_styled.ColumnsVisibilityMenuHeader, {
    use: "subtitle2",
    tag: "h6"
  }, "Toggle column visibility"), /*#__PURE__*/_react.default.createElement(_Menu.MenuDivider, null), options.map(function (option) {
    return /*#__PURE__*/_react.default.createElement(_styled.ColumnsVisibilityMenuItem, {
      key: option.id
    }, /*#__PURE__*/_react.default.createElement(_Checkbox.Checkbox, {
      label: option.header,
      onChange: option.onChange,
      value: option.getValue()
    }));
  }));
};

//# sourceMappingURL=ColumnsVisibility.js.map