import React from "react";
import { DataTableCellProps } from "@rmwc/data-table";
import { ColumnSort, OnChangeFn, Row, SortingState, VisibilityState } from "@tanstack/react-table";
import "@rmwc/data-table/data-table.css";
export interface Column<T> {
    header: string | number | JSX.Element;
    cell?: (row: T) => string | number | JSX.Element | null;
    meta?: DataTableCellProps;
    size?: number;
    className?: string;
    enableSorting?: boolean;
    enableResizing?: boolean;
    enableHiding?: boolean;
}
export type Columns<T> = {
    [P in keyof T]?: Column<T>;
};
export type DefaultData = {
    id: string;
    $selectable?: boolean;
};
export type TableRow<T> = Row<DefaultData & T>;
export type Sorting = SortingState;
export { ColumnSort };
export type OnSortingChange = OnChangeFn<Sorting>;
export type ColumnVisibility = VisibilityState;
export type OnColumnVisibilityChange = OnChangeFn<ColumnVisibility>;
interface Props<T> {
    /**
     * Show or hide borders.
     */
    bordered?: boolean;
    /**
     * Controls whether "select all" action is allowed.
     */
    canSelectAllRows?: boolean;
    /**
     * Columns definition.
     */
    columns: Columns<T>;
    /**
     * The column visibility state.
     */
    columnVisibility?: ColumnVisibility;
    /**
     * Callback that receives current column visibility state.
     */
    onColumnVisibilityChange?: OnColumnVisibilityChange;
    /**
     * Data to display into DataTable body.
     */
    data: T[];
    /**
     * Callback that is called to determine if the row is selectable.
     */
    isRowSelectable?: (row: Row<T>) => boolean;
    /**
     * Render the skeleton state at the initial data loading.
     */
    loadingInitial?: boolean;
    /**
     * Callback that receives the selected rows.
     */
    onSelectRow?: (rows: T[]) => void;
    /**
     * Callback that receives the toggled row.
     */
    onToggleRow?: (row: T) => void;
    /**
     * Callback that receives current sorting state.
     */
    onSortingChange?: OnSortingChange;
    /**
     * Selected rows.
     */
    selectedRows?: T[];
    /**
     * Sorting state.
     */
    sorting?: Sorting;
    /**
     * Initial sorting state.
     */
    initialSorting?: Sorting;
    /**
     * The number of columns to affix to the side of the table when scrolling.
     */
    stickyColumns?: number;
    /**
     * The number of rows to affix to the top of the table when scrolling.
     */
    stickyRows?: number;
}
export declare const DataTable: <T extends Record<string, any> & DefaultData>({ data: initialData, columns: initialColumns, onSelectRow, onToggleRow, loadingInitial, stickyColumns, stickyRows, bordered, sorting, columnVisibility, onColumnVisibilityChange, onSortingChange, isRowSelectable, canSelectAllRows, selectedRows, initialSorting }: Props<T>) => React.JSX.Element;
