"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard").default;
var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "ColumnSort", {
  enumerable: true,
  get: function get() {
    return _reactTable.ColumnSort;
  }
});
exports.DataTable = void 0;
var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));
var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));
var _toConsumableArray2 = _interopRequireDefault(require("@babel/runtime/helpers/toConsumableArray"));
var _objectSpread3 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread2"));
var _react = _interopRequireWildcard(require("react"));
var _dataTable = require("@rmwc/data-table");
var _reactTable = require("@tanstack/react-table");
var _Checkbox = require("../Checkbox");
var _Skeleton = require("../Skeleton");
var _ColumnsVisibility = require("./ColumnsVisibility");
require("@rmwc/data-table/data-table.css");
var _styled = require("./styled");
var defineColumns = function defineColumns(columns, options) {
  var canSelectAllRows = options.canSelectAllRows,
    onSelectRow = options.onSelectRow,
    onToggleRow = options.onToggleRow,
    loadingInitial = options.loadingInitial;
  return (0, _react.useMemo)(function () {
    var columnsList = Object.keys(columns).map(function (key) {
      return (0, _objectSpread3.default)({
        id: key
      }, columns[key]);
    });
    var defaults = columnsList.map(function (column) {
      var _cell = column.cell,
        className = column.className,
        _column$enableHiding = column.enableHiding,
        enableHiding = _column$enableHiding === void 0 ? true : _column$enableHiding,
        _column$enableResizin = column.enableResizing,
        enableResizing = _column$enableResizin === void 0 ? true : _column$enableResizin,
        _column$enableSorting = column.enableSorting,
        enableSorting = _column$enableSorting === void 0 ? false : _column$enableSorting,
        _header = column.header,
        id = column.id,
        meta = column.meta,
        _column$size = column.size,
        size = _column$size === void 0 ? 100 : _column$size;
      return {
        id: id,
        accessorKey: id,
        header: function header() {
          return _header;
        },
        cell: function cell(info) {
          if (_cell && typeof _cell === "function") {
            return _cell(info.row.original);
          } else {
            // Automatically convert any cell value to a string for rendering,
            // ensuring the table displays values correctly. This aligns with React's
            // rendering, which expects JSX, strings or null.
            // https://github.com/TanStack/table/issues/1042
            return info.getValue() ? String(info.getValue()) : null;
          }
        },
        enableSorting: enableSorting,
        meta: (0, _objectSpread3.default)((0, _objectSpread3.default)({}, meta), {}, {
          className: className
        }),
        enableResizing: enableResizing,
        size: size,
        enableHiding: enableHiding
      };
    });
    var isSelectable = onToggleRow || onSelectRow;
    var select = isSelectable ? [{
      id: "datatable-select-column",
      header: function header(_ref) {
        var table = _ref.table;
        if (!canSelectAllRows) {
          return null;
        }
        return !loadingInitial && /*#__PURE__*/_react.default.createElement(_Checkbox.Checkbox, {
          indeterminate: table.getIsSomeRowsSelected(),
          value: table.getIsAllRowsSelected(),
          onChange: function onChange(e) {
            return table.toggleAllPageRowsSelected(e);
          }
        });
      },
      cell: function cell(info) {
        if (!info.row.getCanSelect()) {
          return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null);
        }
        return /*#__PURE__*/_react.default.createElement(_Checkbox.Checkbox, {
          indeterminate: info.row.getIsSomeSelected(),
          value: info.row.getIsSelected(),
          onChange: info.row.getToggleSelectedHandler()
        });
      },
      enableSorting: false,
      enableResizing: false,
      enableHiding: false,
      size: 56
    }] : [];
    return [].concat(select, (0, _toConsumableArray2.default)(defaults)).map(function (column) {
      if (loadingInitial) {
        return (0, _objectSpread3.default)((0, _objectSpread3.default)({}, column), {}, {
          cell: function cell() {
            return /*#__PURE__*/_react.default.createElement(_Skeleton.Skeleton, {
              containerClassName: "table-skeleton-container"
            });
          }
        });
      }
      return column;
    });
  }, [columns, onSelectRow, onToggleRow, loadingInitial]);
};
var ColumnDirection = function ColumnDirection(_ref2) {
  var direction = _ref2.direction;
  if (direction) {
    return /*#__PURE__*/_react.default.createElement(_styled.ColumnDirectionWrapper, null, /*#__PURE__*/_react.default.createElement(_styled.ColumnDirectionIcon, {
      direction: direction
    }));
  }
  return null;
};
var typedMemo = _react.memo;
var TableCell = function TableCell(_ref3) {
  var cell = _ref3.cell,
    getColumnWidth = _ref3.getColumnWidth;
  var width = getColumnWidth(cell.column);
  return /*#__PURE__*/_react.default.createElement(_styled.DataTableCell, Object.assign({}, cell.column.columnDef.meta, {
    style: {
      width: width,
      maxWidth: width
    }
  }), /*#__PURE__*/_react.default.createElement(_styled.ColumnCellWrapper, null, (0, _reactTable.flexRender)(cell.column.columnDef.cell, cell.getContext())));
};
var MemoTableCell = typedMemo(TableCell);
var TableRow = function TableRow(_ref4) {
  var selected = _ref4.selected,
    cells = _ref4.cells,
    getColumnWidth = _ref4.getColumnWidth;
  return /*#__PURE__*/_react.default.createElement(_dataTable.DataTableRow, {
    selected: selected
  }, cells.map(function (cell) {
    return /*#__PURE__*/_react.default.createElement(MemoTableCell, {
      key: cell.id,
      cell: cell,
      getColumnWidth: getColumnWidth,
      selected: selected
    });
  }));
};
var MemoTableRow = typedMemo(TableRow);

/**
 * Empty array must be defined outside of the React component so it does not force rerendering of the DataTable
 */
var emptyArray = Array(10).fill({});
var DataTable = exports.DataTable = function DataTable(_ref5) {
  var initialData = _ref5.data,
    initialColumns = _ref5.columns,
    onSelectRow = _ref5.onSelectRow,
    onToggleRow = _ref5.onToggleRow,
    loadingInitial = _ref5.loadingInitial,
    stickyColumns = _ref5.stickyColumns,
    stickyRows = _ref5.stickyRows,
    bordered = _ref5.bordered,
    sorting = _ref5.sorting,
    columnVisibility = _ref5.columnVisibility,
    onColumnVisibilityChange = _ref5.onColumnVisibilityChange,
    onSortingChange = _ref5.onSortingChange,
    isRowSelectable = _ref5.isRowSelectable,
    _ref5$canSelectAllRow = _ref5.canSelectAllRows,
    canSelectAllRows = _ref5$canSelectAllRow === void 0 ? true : _ref5$canSelectAllRow,
    _ref5$selectedRows = _ref5.selectedRows,
    selectedRows = _ref5$selectedRows === void 0 ? [] : _ref5$selectedRows,
    initialSorting = _ref5.initialSorting;
  var tableRef = (0, _react.useRef)(null);
  var _useState = (0, _react.useState)(1),
    _useState2 = (0, _slicedToArray2.default)(_useState, 2),
    tableWidth = _useState2[0],
    setTableWidth = _useState2[1];
  var data = loadingInitial ? emptyArray : initialData;
  (0, _react.useEffect)(function () {
    var updateElementWidth = function updateElementWidth() {
      if (tableRef.current) {
        var width = tableRef.current.clientWidth;
        setTableWidth(width);
      }
    };
    updateElementWidth();
    window.addEventListener("resize", updateElementWidth);
    return function () {
      window.removeEventListener("resize", updateElementWidth);
    };
  }, [tableRef.current]);
  var rowSelection = (0, _react.useMemo)(function () {
    return selectedRows.reduce(function (acc, item) {
      var recordIndex = data.findIndex(function (rec) {
        return rec.id === item.id;
      });
      return (0, _objectSpread3.default)((0, _objectSpread3.default)({}, acc), {}, (0, _defineProperty2.default)({}, recordIndex, true));
    }, {});
  }, [selectedRows, data]);
  var onRowSelectionChange = function onRowSelectionChange(updater) {
    var newSelection = typeof updater === "function" ? updater(rowSelection) : updater;

    /**
     * `@tanstack/react-table` isn't telling us what row was selected or deselected. It simply gives us
     * the new selection state (an object with row indexes that are currently selected).
     *
     * To figure out what row was toggled, we need to calculate the difference between the old selection
     * and the new selection. What we're doing here is:
     * - find all items that were present in the previous selection, but are no longer present in the new selection
     * - find all items that are present in the new selection, but were not present in the previous selection
     */
    var toggledRows = [].concat((0, _toConsumableArray2.default)(Object.keys(rowSelection).filter(function (x) {
      return !(x in newSelection);
    })), (0, _toConsumableArray2.default)(Object.keys(newSelection).filter(function (x) {
      return !(x in rowSelection);
    })));

    // If the difference is only 1 item, and `onToggleRow` is available, execute that.
    if (toggledRows.length === 1 && typeof onToggleRow === "function") {
      onToggleRow(data[parseInt(toggledRows[0])]);
      return;
    } else if (typeof onSelectRow === "function") {
      var selection = Object.keys(newSelection).map(function (key) {
        return data[parseInt(key)];
      });
      onSelectRow(selection);
    }
  };
  var tableSorting = (0, _react.useMemo)(function () {
    if (!Array.isArray(sorting) || !sorting.length) {
      return initialSorting;
    }
    return sorting;
  }, [sorting]);
  var columns = defineColumns(initialColumns, {
    canSelectAllRows: canSelectAllRows,
    onSelectRow: onSelectRow,
    onToggleRow: onToggleRow,
    loadingInitial: loadingInitial
  });
  var table = (0, _reactTable.useReactTable)({
    data: data,
    columns: columns,
    enableColumnResizing: true,
    columnResizeMode: "onChange",
    getCoreRowModel: (0, _reactTable.getCoreRowModel)(),
    getSortedRowModel: (0, _reactTable.getSortedRowModel)(),
    state: {
      rowSelection: rowSelection,
      sorting: tableSorting,
      columnVisibility: columnVisibility
    },
    enableRowSelection: isRowSelectable,
    onRowSelectionChange: onRowSelectionChange,
    enableSorting: !!onSortingChange,
    enableSortingRemoval: false,
    manualSorting: true,
    onSortingChange: onSortingChange,
    enableHiding: !!onColumnVisibilityChange,
    onColumnVisibilityChange: onColumnVisibilityChange
  });
  var getColumnWidth = (0, _react.useCallback)(function (column) {
    if (!column.getCanResize()) {
      return column.getSize();
    }
    var tableSize = table.getTotalSize();
    var columnSize = column.getSize();
    return Math.ceil(columnSize * tableWidth / tableSize);
  }, [table, tableWidth]);
  /**
   * Had to memoize the rows to avoid browser freeze.
   */
  var tableRows = (0, _react.useMemo)(function () {
    return table.getRowModel().rows;
  }, [table, data, columns]);
  return /*#__PURE__*/_react.default.createElement("div", {
    ref: tableRef
  }, /*#__PURE__*/_react.default.createElement(_styled.Table, {
    stickyColumns: stickyColumns,
    stickyRows: stickyRows,
    bordered: bordered
  }, /*#__PURE__*/_react.default.createElement(_dataTable.DataTableContent, null, /*#__PURE__*/_react.default.createElement(_dataTable.DataTableHead, null, table.getHeaderGroups().map(function (headerGroup) {
    return /*#__PURE__*/_react.default.createElement(_dataTable.DataTableRow, {
      key: headerGroup.id
    }, headerGroup.headers.map(function (header, index) {
      var isLastCell = index === headerGroup.headers.length - 1;
      var width = getColumnWidth(header.column);
      return /*#__PURE__*/_react.default.createElement(_styled.TableHeadCell, Object.assign({
        key: header.id
      }, header.column.columnDef.meta, {
        colSpan: header.colSpan,
        style: {
          width: width,
          maxWidth: width
        }
      }), header.isPlaceholder ? null : /*#__PURE__*/_react.default.createElement(_styled.ColumnHeaderWrapper, {
        onClick: header.column.getToggleSortingHandler(),
        sortable: header.column.getCanSort(),
        isLastCell: isLastCell
      }, (0, _reactTable.flexRender)(header.column.columnDef.header, header.getContext()), /*#__PURE__*/_react.default.createElement(ColumnDirection, {
        direction: header.column.getIsSorted() || undefined
      }), isLastCell && /*#__PURE__*/_react.default.createElement(_ColumnsVisibility.ColumnsVisibility, {
        columns: table.getAllColumns()
      })), header.column.getCanResize() && /*#__PURE__*/_react.default.createElement(_styled.Resizer, {
        onMouseDown: header.getResizeHandler(),
        onTouchStart: header.getResizeHandler(),
        isResizing: header.column.getIsResizing()
      }));
    }));
  })), /*#__PURE__*/_react.default.createElement(_dataTable.DataTableBody, null, tableRows.map(function (row) {
    var id = row.original.id || row.id;
    return /*#__PURE__*/_react.default.createElement(MemoTableRow, {
      key: id,
      cells: row.getVisibleCells(),
      selected: row.getIsSelected(),
      getColumnWidth: getColumnWidth
    });
  })))));
};

//# sourceMappingURL=DataTable.js.map