import React from "react";
export interface ApplyValueCb<TValue> {
    (value: TValue): void;
}
/**
 * This component is used to wrap Input and Textarea components to optimize form re-render.
 * These 2 are the only components that trigger form model change on each character input.
 * This means, whenever you type a letter an entire form re-renders.
 * On complex forms you will feel and see a significant delay if this component is not used.
 *
 * The logic behind this component is to serve as a middleware between Form and Input/Textarea, and only notify form of a change when
 * a user stops typing for given period of time (400ms by default).
 */
export interface OnChangeCallable<TValue = any> {
    (value: TValue, cb?: ApplyValueCb<TValue>): void;
}
interface OnBlurCallable {
    (ev: React.SyntheticEvent): void;
}
interface OnKeyDownCallable {
    (ev: React.KeyboardEvent<HTMLInputElement>): void;
}
interface ChildrenCallableParams<TValue> {
    value: TValue;
    onChange: OnChangeCallable<TValue>;
}
interface ChildrenCallable<TValue> {
    (params: ChildrenCallableParams<TValue>): React.ReactElement;
}
export interface DelayedOnChangeProps<TValue> {
    value?: TValue;
    delay?: number;
    onChange?: OnChangeCallable<TValue>;
    onBlur?: OnBlurCallable;
    onKeyDown?: OnKeyDownCallable;
    children: React.ReactNode | ChildrenCallable<TValue | undefined>;
}
export declare const DelayedOnChange: <TValue = any>({ children, ...other }: DelayedOnChangeProps<TValue>) => React.ReactElement<any, string | React.JSXElementConstructor<any>>;
export {};
