import React from "react";
import { DialogActionsProps as RmwcDialogActionsProps, DialogButtonProps as RmwcDialogButtonProps, DialogContentProps as RmwcDialogContentProps, DialogOnCloseEventT, DialogProps as RmwcDialogProps, DialogTitleProps as RmwcDialogTitleProps } from "@rmwc/dialog";
export type DialogOnClose = (event: DialogOnCloseEventT) => void;
export interface DialogProps extends RmwcDialogProps {
    className?: string;
    style?: React.CSSProperties;
    onClose?: (evt: DialogOnCloseEventT) => void;
    preventOutsideDismiss?: boolean;
    children?: React.ReactNode;
}
export declare class Dialog extends React.Component<DialogProps> {
    container: HTMLElement;
    constructor(props: DialogProps);
    render(): React.ReactPortal;
}
export interface DialogTitleProps extends RmwcDialogTitleProps {
    /**
     * Title text.
     */
    children: React.ReactNode[] | React.ReactNode;
}
/**
 * Dialog's header, which can accept DialogHeaderTitle component or any other set of components.
 */
export declare const DialogTitle: (props: DialogTitleProps) => React.JSX.Element;
export type DialogContentProps = RmwcDialogContentProps & {
    /**
     * Dialog content.
     */
    children: React.ReactNode[] | React.ReactNode;
    className?: string;
};
/**
 * A simple component for showing dialog's body.
 */
export declare const DialogContent: (props: DialogContentProps) => React.JSX.Element;
export interface DialogActionsProps extends RmwcDialogActionsProps {
    /**
     * Action buttons.
     */
    children: React.ReactNode[] | React.ReactNode;
    style?: React.CSSProperties;
}
/**
 * Can be used to show accept and cancel buttons.
 */
export declare const DialogActions: (props: DialogActionsProps) => React.JSX.Element;
interface DialogButtonProps extends RmwcDialogButtonProps {
    /**
     * Callback to execute then button is clicked.
     */
    onClick?: (e: React.MouseEvent) => void;
    className?: string;
}
/**
 * Use this to show a simple button.
 */
export declare const DialogButton: (props: DialogButtonProps) => React.JSX.Element;
interface DialogCancelProps extends RmwcDialogButtonProps {
    /**
     * Callback to execute then button is clicked.
     */
    onClick?: (e: React.MouseEvent) => void;
}
/**
 * Use this to close the dialog without taking any additional action.
 */
export declare const DialogCancel: (props: DialogCancelProps) => React.JSX.Element;
interface DialogAcceptProps extends RmwcDialogButtonProps {
    /**
     * Callback to execute then button is clicked.
     */
    onClick?: (e: React.MouseEvent) => void;
}
/**
 * Use this to close the dialog without taking any additional action.
 */
export declare const DialogAccept: (props: DialogAcceptProps) => React.JSX.Element;
export {};
