"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Input = void 0;
var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutProperties"));
var _react = _interopRequireWildcard(require("react"));
var _textfield = require("@rmwc/textfield");
var _FormElementMessage = require("../FormElementMessage");
var _pick = _interopRequireDefault(require("lodash/pick"));
var _classnames = _interopRequireDefault(require("classnames"));
var _styled = require("./styled");
var _excluded = ["autoFocus", "value", "label", "description", "placeholder", "rows", "validation", "icon", "trailingIcon", "onEnter", "size"];
/**
 * Use Input component to store short string values, like first name, last name, e-mail etc.
 * Additionally, with rows prop, it can also be turned into a text area, to store longer strings.
 */

// IconProps directly passed to RMWC
var rmwcProps = ["label", "type", "step", "disabled", "readOnly", "placeholder", "outlined", "onKeyDown", "onKeyPress", "onKeyUp", "onFocus", "rootProps", "fullwidth", "inputRef", "className", "maxLength", "characterCount", "autoComplete"];
var Input = exports.Input = function Input(props) {
  var onChange = (0, _react.useCallback)(function (e) {
    var onChange = props.onChange,
      rawOnChange = props.rawOnChange;
    if (!onChange) {
      return;
    }

    // @ts-expect-error
    onChange(rawOnChange ? e : e.target.value);
  }, [props.onChange, props.rawOnChange]);
  var onBlur = (0, _react.useCallback)(async function (e) {
    var validate = props.validate,
      onBlur = props.onBlur;
    if (validate) {
      // Since we are accessing event in an async operation, we need to persist it.
      // See https://reactjs.org/docs/events.html#event-pooling.
      e.persist();
      await validate();
    }
    onBlur && onBlur(e);
  }, [props.validate, props.onBlur]);
  var autoFocus = props.autoFocus,
    value = props.value,
    label = props.label,
    description = props.description,
    placeholder = props.placeholder,
    rows = props.rows,
    validation = props.validation,
    icon = props.icon,
    trailingIcon = props.trailingIcon,
    onEnter = props.onEnter,
    size = props.size,
    rest = (0, _objectWithoutProperties2.default)(props, _excluded);
  var inputValue = value;
  if (value === null || typeof value === "undefined") {
    inputValue = "";
  }
  var _ref = validation || {},
    validationIsValid = _ref.isValid,
    validationMessage = _ref.message;
  var inputOnKeyDown = (0, _react.useCallback)(function (e) {
    if (typeof onEnter === "function" && e.key === "Enter") {
      onEnter();
    }
    if (typeof rest.onKeyDown === "function") {
      return rest.onKeyDown(e);
    }
  }, [rest.onKeyDown, onEnter]);
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_textfield.TextField, Object.assign({}, (0, _pick.default)(rest, rmwcProps), {
    onKeyDown: inputOnKeyDown,
    autoFocus: autoFocus,
    textarea: Boolean(rows),
    value: inputValue,
    onChange: onChange,
    onBlur: onBlur,
    label: label,
    icon: icon,
    placeholder: placeholder,
    trailingIcon: trailingIcon,
    rows: rows,
    className: (0, _classnames.default)("webiny-ui-input", _styled.webinyInputStyles, props.size ? "webiny-ui-input--size-".concat(size) : null),
    "data-testid": props["data-testid"]
  })), validationIsValid === false && /*#__PURE__*/_react.default.createElement(_FormElementMessage.FormElementMessage, {
    error: true
  }, validationMessage), validationIsValid !== false && description && /*#__PURE__*/_react.default.createElement(_FormElementMessage.FormElementMessage, null, description));
};

//# sourceMappingURL=Input.js.map