import React from "react";
import { ListProps as RmwcListProps, ListItemProps as RmwcListItemProps, ListItemTextProps as RmwcListItemTextProps, SimpleListItemProps as RmwcSimpleListItemProps } from "@rmwc/list";
export type ListItemProps = RmwcListItemProps & {
    children: React.ReactNode;
    className?: string;
    style?: React.CSSProperties;
    onClick?: (e: React.MouseEvent) => void;
};
/**
 * ListItem components are placed as direct children to List component.
 * @param props
 * @returns {*}
 * @constructor
 */
export declare const ListItem: (props: ListItemProps) => React.JSX.Element;
export type ListProps = RmwcListProps & {
    children?: any;
    className?: string;
    style?: React.CSSProperties;
};
/**
 * Use List component to display data and offer additional actions if needed.
 */
export declare class List extends React.Component<ListProps> {
    render(): React.JSX.Element;
}
export type ListItemTextProps = RmwcListItemTextProps & {
    children: React.ReactNode;
    className?: string;
    onClick?: (e: React.MouseEvent<HTMLDivElement, MouseEvent>) => void;
};
/**
 * Used to show regular text in list items.
 * @param props
 * @returns {*}
 * @constructor
 */
export declare const ListItemText: (props: ListItemTextProps) => React.JSX.Element;
export type ListItemTextPrimaryProps = {
    /**
     * Text content
     */
    children: React.ReactNode;
};
export declare const ListItemTextPrimary: (props: ListItemTextPrimaryProps) => React.JSX.Element;
export type ListItemTextSecondaryProps = {
    /**
     * Text content
     */
    children: React.ReactNode;
};
/**
 * Used to show secondary text in list items.
 * @param props
 * @returns {*}
 * @constructor
 */
export declare const ListItemTextSecondary: (props: ListItemTextSecondaryProps) => React.JSX.Element;
export type ListItemGraphicProps = {
    children: React.ReactNode;
    className?: string;
};
/**
 * Can be used to show an icon or any other custom element. Rendered on the left side.
 * @param props
 * @returns {*}
 * @constructor
 */
export declare const ListItemGraphic: (props: ListItemGraphicProps) => React.JSX.Element;
export type ListItemMetaProps = {
    children: React.ReactNode;
    className?: string;
};
/**
 * Can be used to show an icon or any other custom element. Rendered on the right side.
 * @param props
 * @returns {*}
 * @constructor
 */
export declare const ListItemMeta: (props: ListItemMetaProps) => React.JSX.Element;
export type ListTopCaptionProps = {
    children: React.ReactNode;
};
/**
 * Can be used to show a top caption inside ListItemMeta component.
 * @param props
 * @returns {*}
 * @constructor
 */
export declare const ListTopCaption: (props: ListTopCaptionProps) => React.JSX.Element;
export type ListBottomCaptionProps = {
    children: React.ReactNode;
};
/**
 * Can be used to show a bottom caption inside ListItemMeta component.
 * @param props
 * @returns {*}
 * @constructor
 */
export declare const ListBottomCaption: (props: ListBottomCaptionProps) => React.JSX.Element;
export type ListTextOverlineProps = {
    children: React.ReactNode;
};
/**
 * Can be used to show an overline text inside ListItem component.
 * @param props
 * @returns {*}
 * @constructor
 */
export declare const ListTextOverline: (props: ListTextOverlineProps) => React.JSX.Element;
export type ListActionsProps = {
    children: React.ReactNode;
};
/**
 * Used to contain the actions inside ListItemMate component.
 * @param props
 * @returns {*}
 * @constructor
 */
export declare const ListActions: (props: ListActionsProps) => React.JSX.Element;
export type ListSelectBoxProps = {
    children: React.ReactNode;
};
/**
 * Used to hold the Checkbox element for multi-select options.
 * @param {*} props
 */
export declare const ListSelectBox: (props: ListSelectBoxProps) => React.JSX.Element;
export declare const SimpleListItem: (props: RmwcSimpleListItemProps & {
    onClick?: any;
}) => React.JSX.Element;
