"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.MenuItem = exports.MenuDivider = exports.Menu = void 0;
var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));
var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutProperties"));
var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));
var _react = _interopRequireWildcard(require("react"));
var _menu = require("@rmwc/menu");
var _emotion = require("emotion");
var _classnames = _interopRequireDefault(require("classnames"));
var _excluded = ["disabled", "className"];
var style = {
  disabledMenuItem: (0, _emotion.css)({
    opacity: 0.5,
    pointerEvents: "none"
  })
};
/**
 * Use Menu component to display a list of choices, once the handler is triggered.
 */
var Menu = exports.Menu = function Menu(props) {
  var children = props.children,
    handle = props.handle,
    _props$anchor = props.anchor,
    anchor = _props$anchor === void 0 ? "topStart" : _props$anchor,
    className = props.className,
    disabled = props.disabled,
    onOpen = props.onOpen,
    onClose = props.onClose,
    onSelect = props.onSelect,
    open = props.open,
    render = props.render,
    renderToPortal = props.renderToPortal,
    _props$portalZIndex = props.portalZIndex,
    portalZIndex = _props$portalZIndex === void 0 ? 99 : _props$portalZIndex;
  var _useState = (0, _react.useState)(false),
    _useState2 = (0, _slicedToArray2.default)(_useState, 2),
    menuIsOpen = _useState2[0],
    setMenuIsOpen = _useState2[1];
  (0, _react.useEffect)(function () {
    if (typeof open === "boolean") {
      setMenuIsOpen(open);
    }
  }, [open]);
  var openMenu = (0, _react.useCallback)(function () {
    if (disabled) {
      return;
    }
    setMenuIsOpen(true);
    if (onOpen) {
      onOpen();
    }
  }, [disabled, onOpen]);
  var closeMenu = (0, _react.useCallback)(function () {
    setMenuIsOpen(false);
    if (onClose) {
      onClose();
    }
  }, [onClose]);
  var renderMenuWithPortal = function renderMenuWithPortal() {
    return /*#__PURE__*/_react.default.createElement(_menu.Menu, {
      anchorCorner: anchor,
      open: menuIsOpen,
      className: className,
      onClose: closeMenu,
      onSelect: onSelect,
      renderToPortal: true,
      style: {
        zIndex: portalZIndex
      } // Fixes Menu in Drawers
    }, /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, children));
  };
  var renderCustomContent = function renderCustomContent() {
    var renderer = render || children;
    return /*#__PURE__*/_react.default.createElement(_menu.MenuSurface, {
      open: menuIsOpen,
      onClose: closeMenu,
      renderToPortal: renderToPortal
    }, typeof renderer === "function" ? renderer({
      closeMenu: closeMenu
    }) : renderer);
  };
  return /*#__PURE__*/_react.default.createElement(_menu.MenuSurfaceAnchor, {
    "data-testid": props["data-testid"]
  }, Array.isArray(children) ? renderMenuWithPortal() : renderCustomContent(), handle && /*#__PURE__*/_react.default.cloneElement(handle, {
    onClick: openMenu
  }));
};
var MenuDivider = exports.MenuDivider = function MenuDivider() {
  return /*#__PURE__*/_react.default.createElement("li", {
    className: "mdc-list-divider",
    role: "separator"
  });
};
var MenuItem = exports.MenuItem = function MenuItem(_ref) {
  var disabled = _ref.disabled,
    className = _ref.className,
    rest = (0, _objectWithoutProperties2.default)(_ref, _excluded);
  return /*#__PURE__*/_react.default.createElement(_menu.MenuItem, Object.assign({}, rest, {
    className: (0, _classnames.default)(className, (0, _defineProperty2.default)({}, style.disabledMenuItem, disabled))
  }));
};

//# sourceMappingURL=Menu.js.map