"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.RichTextEditor = void 0;
var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));
var _objectSpread2 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread2"));
var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutProperties"));
var _react = _interopRequireWildcard(require("react"));
var _editorjs = _interopRequireDefault(require("@editorjs/editorjs"));
var _FormElementMessage = require("../FormElementMessage");
var _emotion = require("emotion");
var _classnames = _interopRequireDefault(require("classnames"));
var _generateId = require("@webiny/utils/generateId");
var _excluded = ["value", "context", "onReady"];
var classes = {
  wrapper: (0, _emotion.css)({
    backgroundColor: "var(--mdc-theme-background)",
    padding: "20px 16px 6px"
  }),
  label: (0, _emotion.css)({
    marginBottom: "10px !important"
  }),
  disable: (0, _emotion.css)({
    opacity: 0.7,
    pointerEvents: "none"
  })
};
var waitForDom = function waitForDom(id, callback) {
  var timeSpent = 0;
  var interval = setInterval(function () {
    if (timeSpent > 1000) {
      clearInterval(interval);
      return;
    }
    var dom = document.querySelector("#".concat(id));
    if (!dom) {
      timeSpent += 10;
      return;
    }
    clearInterval(interval);
    callback();
  }, 10);
  return function () {
    clearInterval(interval);
  };
};
var RichTextEditor = exports.RichTextEditor = function RichTextEditor(props) {
  var elementId = (0, _react.useRef)("rte-" + (0, _generateId.generateAlphaNumericId)());
  var editorRef = (0, _react.useRef)();
  (0, _react.useEffect)(function () {
    var value = props.value,
      context = props.context,
      _onReady = props.onReady,
      nativeProps = (0, _objectWithoutProperties2.default)(props, _excluded);
    var initialData = value ? {
      blocks: value
    } : {
      blocks: []
    };
    var clearWait = waitForDom(elementId.current, function () {
      editorRef.current = new _editorjs.default((0, _objectSpread2.default)((0, _objectSpread2.default)({}, nativeProps), {}, {
        holder: elementId.current,
        logLevel: "ERROR",
        data: initialData,
        onChange: async function onChange() {
          if (!editorRef.current) {
            return;
          }
          var _await$editorRef$curr = await editorRef.current.save(),
            data = _await$editorRef$curr.blocks;
          if (!props.onChange) {
            return;
          }
          props.onChange(data);
        },
        onReady: function onReady() {
          if (typeof _onReady !== "function") {
            return;
          }
          _onReady({
            editor: editorRef.current,
            initialData: initialData
          });
        },
        tools: Object.keys(props.tools || {}).reduce(function (tools, name) {
          var tool = props.tools ? props.tools[name] : null;
          if (!tool) {
            return tools;
          }
          tools[name] = tool;
          if (!tool.config) {
            tool.config = {
              context: context
            };
          } else if (typeof tool.config === "function") {
            tool.config = tool.config();
          } else {
            tool.config = (0, _objectSpread2.default)((0, _objectSpread2.default)({}, tool.config), {}, {
              context: context
            });
          }
          return tools;
        }, {})
      }));
    });
    return function () {
      clearWait();
      if (!editorRef.current || typeof editorRef.current.destroy !== "function") {
        return;
      }
      editorRef.current.destroy();
    };
  }, []);
  var label = props.label,
    description = props.description,
    disabled = props.disabled,
    validation = props.validation,
    className = props.className;
  return /*#__PURE__*/_react.default.createElement(_react.Fragment, null, /*#__PURE__*/_react.default.createElement("div", {
    className: (0, _classnames.default)(classes.wrapper, className, (0, _defineProperty2.default)({}, classes.disable, disabled))
  }, label && /*#__PURE__*/_react.default.createElement("div", {
    className: (0, _classnames.default)("mdc-text-field-helper-text mdc-text-field-helper-text--persistent", classes.label)
  }, label), /*#__PURE__*/_react.default.createElement("div", {
    id: elementId.current
  })), validation && validation.isValid === false && /*#__PURE__*/_react.default.createElement(_FormElementMessage.FormElementMessage, {
    error: true
  }, validation.message), validation && validation.isValid !== false && description && /*#__PURE__*/_react.default.createElement(_FormElementMessage.FormElementMessage, null, description));
};

//# sourceMappingURL=RichTextEditor.js.map