"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.Select = void 0;
var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutProperties"));
var _createForOfIteratorHelper2 = _interopRequireDefault(require("@babel/runtime/helpers/createForOfIteratorHelper"));
var _react = _interopRequireWildcard(require("react"));
var _select = require("@rmwc/select");
var _FormElementMessage = require("../FormElementMessage");
var _classnames = _interopRequireDefault(require("classnames"));
var _styled = require("./styled");
var _excluded = ["value", "description", "validation"];
/**
 * TODO verify that this is correct method get all options.
 */
var getOptions = function getOptions(initialOptions) {
  if (!initialOptions) {
    return [];
  } else if (Array.isArray(initialOptions)) {
    var options = [];
    var _iterator = (0, _createForOfIteratorHelper2.default)(initialOptions),
      _step;
    try {
      for (_iterator.s(); !(_step = _iterator.n()).done;) {
        var option = _step.value;
        if (typeof option === "string") {
          options.push({
            label: option,
            value: option
          });
          continue;
        }
        options.push({
          label: option.label,
          value: option.value,
          options: option.options
        });
      }
    } catch (err) {
      _iterator.e(err);
    } finally {
      _iterator.f();
    }
    return options;
  }
  return Object.keys(initialOptions).map(function (key) {
    return {
      label: initialOptions[key],
      value: key
    };
  });
};

/**
 * Select component lets users choose a value from given set of options.
 */
var skipProps = ["validate", "form"];
var getRmwcProps = function getRmwcProps(props) {
  var newProps = {};
  Object.keys(props).filter(function (name) {
    return !skipProps.includes(name);
  })
  // @ts-expect-error
  .forEach(function (name) {
    return newProps[name] = props[name];
  });
  return newProps;
};
/**
 * We check for null and undefined in the value because React is complaining about those values.
 * Error says to use the empty string in null/undefined case.
 */
var Select = exports.Select = function Select(props) {
  var initialValue = props.value,
    description = props.description,
    validation = props.validation,
    other = (0, _objectWithoutProperties2.default)(props, _excluded);
  var value = initialValue === null || initialValue === undefined ? "" : initialValue;
  var _ref = validation || {},
    validationIsValid = _ref.isValid,
    validationMessage = _ref.message;
  var options = getOptions(other.options);

  // Memoize the label and placeholder values based on the component size.
  var _useMemo = (0, _react.useMemo)(function () {
      var size = props.size,
        label = props.label,
        placeholderText = props.placeholder;

      // If `placeholderText` is null, undefined, or an empty string after trimming, `placeholder` will be set to `undefined`.
      var placeholder = placeholderText?.trim() || undefined;

      // For small or medium size, we set only the placeholder, using label as fallback.
      if (size === "small" || size === "medium") {
        return {
          label: undefined,
          placeholder: placeholder || label
        };
      }

      // For other sizes, use the provided label and placeholder.
      return {
        label: label,
        placeholder: placeholder
      };
    }, [props.label, props.placeholder, props.size]),
    label = _useMemo.label,
    placeholder = _useMemo.placeholder;
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_select.Select, Object.assign({}, getRmwcProps(other), {
    ref: undefined,
    options: options,
    value: value,
    label: label,
    placeholder: placeholder,
    className: (0, _classnames.default)("webiny-ui-select mdc-ripple-surface mdc-ripple-upgraded", _styled.webinySelect, props.size ? "webiny-ui-select--size-".concat(props.size) : null, props.className),
    onChange: function onChange(e) {
      props.onChange && props.onChange(e.target.value);
    }
  })), validationIsValid === false && /*#__PURE__*/_react.default.createElement(_FormElementMessage.FormElementMessage, {
    error: true
  }, validationMessage), validationIsValid !== false && description && /*#__PURE__*/_react.default.createElement(_FormElementMessage.FormElementMessage, null, description));
};
var _default = exports.default = Select;

//# sourceMappingURL=Select.js.map