"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.TabsContext = exports.Tabs = void 0;
var _toConsumableArray2 = _interopRequireDefault(require("@babel/runtime/helpers/toConsumableArray"));
var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));
var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutProperties"));
var _react = _interopRequireWildcard(require("react"));
var _classnames = _interopRequireDefault(require("classnames"));
var _tabs = require("@rmwc/tabs");
var _excluded = ["children", "value", "onActivate", "className"];
var disabledStyles = {
  opacity: 0.5,
  pointerEvents: "none"
};
var TabsContext = exports.TabsContext = /*#__PURE__*/(0, _react.createContext)(undefined);

/**
 * Use Tabs component to display a list of choices, once the handler is triggered.
 */
var Tabs = exports.Tabs = function Tabs(_ref) {
  var children = _ref.children,
    value = _ref.value,
    _onActivate = _ref.onActivate,
    className = _ref.className,
    props = (0, _objectWithoutProperties2.default)(_ref, _excluded);
  var _useState = (0, _react.useState)(0),
    _useState2 = (0, _slicedToArray2.default)(_useState, 2),
    activeTabIndex = _useState2[0],
    setActiveIndex = _useState2[1];
  var _useState3 = (0, _react.useState)([]),
    _useState4 = (0, _slicedToArray2.default)(_useState3, 2),
    tabs = _useState4[0],
    setTabs = _useState4[1];
  var activeIndex = value !== undefined ? value : activeTabIndex;

  /* We need to generate a key like this to trigger a proper component re-render when child tabs change. */
  var tabBar = /*#__PURE__*/_react.default.createElement(_tabs.TabBar, {
    key: tabs.map(function (tab) {
      return tab.id;
    }).join(";"),
    className: "webiny-ui-tabs__tab-bar",
    activeTabIndex: activeIndex,
    onActivate: function onActivate(evt) {
      setActiveIndex(evt.detail.index);
      _onActivate && _onActivate(evt.detail.index);
    }
  }, tabs.map(function (item) {
    if (!item.visible) {
      return /*#__PURE__*/_react.default.createElement(_tabs.Tab, {
        tag: "div",
        style: {
          display: "none"
        },
        key: item.id
      });
    }
    var style = item.style || {};
    if (item.disabled) {
      Object.assign(style, disabledStyles);
    }
    return /*#__PURE__*/_react.default.createElement(_tabs.Tab, Object.assign({
      tag: "div",
      style: style,
      key: item.id,
      "data-testid": item["data-testid"]
    }, item.icon ? {
      icon: item.icon
    } : {}), item.label);
  }));
  var content = tabs.filter(Boolean).map(function (tab, index) {
    if (activeIndex === index) {
      return /*#__PURE__*/_react.default.createElement("div", {
        key: index
      }, tab.children);
    } else {
      return /*#__PURE__*/_react.default.createElement("div", {
        key: index,
        style: {
          display: "none"
        }
      }, tab.children);
    }
  });
  var context = (0, _react.useMemo)(function () {
    return {
      addTab: function addTab(props) {
        setTabs(function (tabs) {
          var existingIndex = tabs.findIndex(function (tab) {
            return tab.id === props.id;
          });
          if (existingIndex > -1) {
            return [].concat((0, _toConsumableArray2.default)(tabs.slice(0, existingIndex)), [props], (0, _toConsumableArray2.default)(tabs.slice(existingIndex + 1)));
          }
          return [].concat((0, _toConsumableArray2.default)(tabs), [props]);
        });
      },
      removeTab: function removeTab(id) {
        setTabs(function (tabs) {
          return tabs.filter(function (tab) {
            return tab.id === id;
          });
        });
      }
    };
  }, [setTabs]);
  return /*#__PURE__*/_react.default.createElement("div", {
    id: props.id,
    className: (0, _classnames.default)("webiny-ui-tabs", className)
  }, tabBar, /*#__PURE__*/_react.default.createElement("div", {
    className: "webiny-ui-tabs__content mdc-tab-content"
  }, content), /*#__PURE__*/_react.default.createElement(TabsContext.Provider, {
    value: context
  }, children));
};
Tabs.displayName = "Tabs";

//# sourceMappingURL=Tabs.js.map