"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.Tags = void 0;
var _toConsumableArray2 = _interopRequireDefault(require("@babel/runtime/helpers/toConsumableArray"));
var _objectSpread2 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread2"));
var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutProperties"));
var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));
var _react = _interopRequireWildcard(require("react"));
var _emotion = require("emotion");
var _keycode = _interopRequireDefault(require("keycode"));
var _minimatch = _interopRequireDefault(require("minimatch"));
var _Input = require("../Input");
var _Chips = require("../Chips");
var _baselineClose24px = require("./icons/baseline-close-24px.svg");
var _FormElementMessage = require("../FormElementMessage");
var _excluded = ["validation", "value", "disabled", "onChange", "description", "protectedTags"];
var tagsStyle = (0, _emotion.css)({
  position: "relative",
  ".mdc-elevation--z1": {
    position: "absolute",
    width: "calc(100% - 2px)",
    left: 1,
    top: 56,
    zIndex: 10,
    maxHeight: 200,
    overflowY: "scroll",
    backgroundColor: "var(--mdc-theme-surface)"
  },
  ul: {
    listStyle: "none",
    width: "100%",
    padding: 0,
    li: {
      padding: 10
    }
  }
});
var Tags = exports.Tags = function Tags(props) {
  var _useState = (0, _react.useState)(""),
    _useState2 = (0, _slicedToArray2.default)(_useState, 2),
    inputValue = _useState2[0],
    setInputValue = _useState2[1];
  var validation = props.validation,
    value = props.value,
    disabled = props.disabled,
    onChange = props.onChange,
    description = props.description,
    _props$protectedTags = props.protectedTags,
    protectedTags = _props$protectedTags === void 0 ? [] : _props$protectedTags,
    otherInputProps = (0, _objectWithoutProperties2.default)(props, _excluded);
  var isProtected = (0, _react.useCallback)(function (tag) {
    return protectedTags.some(function (pattern) {
      return (0, _minimatch.default)(tag, pattern);
    });
  }, [protectedTags]);
  var inputProps = (0, _objectSpread2.default)((0, _objectSpread2.default)({}, otherInputProps), {}, {
    value: inputValue,
    onChange: function onChange(inputValue) {
      setInputValue(inputValue);
    },
    onKeyDown: function onKeyDown(ev) {
      if (!onChange) {
        return;
      }
      var newValue = Array.isArray(value) ? (0, _toConsumableArray2.default)(value) : [];

      /**
       * We must cast as keycode only works with Event | string type.
       */
      switch ((0, _keycode.default)(ev)) {
        case "enter":
          if (inputValue) {
            newValue.push(inputValue);
            onChange(newValue);
            setInputValue("");
          }
          break;
        case "backspace":
          if (newValue.length && !inputValue) {
            newValue.splice(-1, 1);
            onChange(newValue);
            break;
          }
      }
    }
  });
  var _ref = validation || {},
    validationIsValid = _ref.isValid,
    validationMessage = _ref.message;
  return /*#__PURE__*/_react.default.createElement("div", {
    className: tagsStyle
  }, /*#__PURE__*/_react.default.createElement("div", null, /*#__PURE__*/_react.default.createElement(_Input.Input, inputProps), validationIsValid === false && /*#__PURE__*/_react.default.createElement(_FormElementMessage.FormElementMessage, {
    error: true
  }, validationMessage), validationIsValid !== false && description && /*#__PURE__*/_react.default.createElement(_FormElementMessage.FormElementMessage, null, description), Array.isArray(value) && value.length ? /*#__PURE__*/_react.default.createElement(_Chips.Chips, {
    disabled: disabled
  }, value.map(function (item, index) {
    return /*#__PURE__*/_react.default.createElement(_Chips.Chip, {
      label: item,
      trailingIcon: isProtected(item) ? null : /*#__PURE__*/_react.default.createElement(_baselineClose24px.ReactComponent, null),
      key: "".concat(item, "-").concat(index),
      onRemove: function onRemove() {
        // On removal, let's update the value and call "onChange" callback.
        if (onChange) {
          var newValue = (0, _toConsumableArray2.default)(value);
          newValue.splice(index, 1);
          onChange(newValue);
        }
      }
    });
  })) : null));
};
var _default = exports.default = Tags;

//# sourceMappingURL=Tags.js.map